==> openshift-model-installer-5.12.3-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/AffinityGroupBuilder.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AffinityGroupBuilder extends io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroupFluentImpl<io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroupBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroup,io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroupBuilder>{
  public AffinityGroupBuilder() {
    this(false);
  }
  public AffinityGroupBuilder(java.lang.Boolean validationEnabled) {
    this(new AffinityGroup(), validationEnabled);
  }
  public AffinityGroupBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroupFluent<?> fluent) {
    this(fluent, false);
  }
  public AffinityGroupBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroupFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AffinityGroup(), validationEnabled);
  }
  public AffinityGroupBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroupFluent<?> fluent,io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroup instance) {
    this(fluent, instance, false);
  }
  public AffinityGroupBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroupFluent<?> fluent,io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroup instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withEnforcing(instance.getEnforcing()); 
    fluent.withName(instance.getName()); 
    fluent.withPriority(instance.getPriority()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AffinityGroupBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroup instance) {
    this(instance,false);
  }
  public AffinityGroupBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroup instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withEnforcing(instance.getEnforcing()); 
    this.withName(instance.getName()); 
    this.withPriority(instance.getPriority()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroupFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.installer.ovirt.v1.AffinityGroup build() {
    AffinityGroup buildable = new AffinityGroup(fluent.getDescription(),fluent.getEnforcing(),fluent.getName(),fluent.getPriority());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AffinityGroupBuilder that = (AffinityGroupBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-installer-6.2.0-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/AffinityGroupBuilder.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AffinityGroupBuilder extends AffinityGroupFluentImpl<AffinityGroupBuilder> implements VisitableBuilder<AffinityGroup,AffinityGroupBuilder>{
  public AffinityGroupBuilder() {
    this(false);
  }
  public AffinityGroupBuilder(Boolean validationEnabled) {
    this(new AffinityGroup(), validationEnabled);
  }
  public AffinityGroupBuilder(AffinityGroupFluent<?> fluent) {
    this(fluent, false);
  }
  public AffinityGroupBuilder(AffinityGroupFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AffinityGroup(), validationEnabled);
  }
  public AffinityGroupBuilder(AffinityGroupFluent<?> fluent,AffinityGroup instance) {
    this(fluent, instance, false);
  }
  public AffinityGroupBuilder(AffinityGroupFluent<?> fluent,AffinityGroup instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDescription(instance.getDescription()); 
    fluent.withEnforcing(instance.getEnforcing()); 
    fluent.withName(instance.getName()); 
    fluent.withPriority(instance.getPriority()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AffinityGroupBuilder(AffinityGroup instance) {
    this(instance,false);
  }
  public AffinityGroupBuilder(AffinityGroup instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDescription(instance.getDescription()); 
    this.withEnforcing(instance.getEnforcing()); 
    this.withName(instance.getName()); 
    this.withPriority(instance.getPriority()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  AffinityGroupFluent<?> fluent;
  Boolean validationEnabled;
  public AffinityGroup build() {
    AffinityGroup buildable = new AffinityGroup(fluent.getDescription(),fluent.getEnforcing(),fluent.getName(),fluent.getPriority());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
